/*******************************************************************************
Copyright 2016 Microchip Technology Inc. (www.microchip.com)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

To request to license the code under the MLA license (www.microchip.com/mla_license), 
please contact mla_licensing@microchip.com
*******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************
/* Standard C includes */
#include <stdint.h>
#include <xc.h>

/* Microchip library includes */
#include "system.h"


/* User defined function */
#include "pic_init.h"
#include "global_define.h"
#include "button_push_detect.h"
#include "led_cont.h"

#include "usb.h"
#include "usb_device_hid.h"

/* Demo project includes */
#include "app_device_keyboard.h"

int main(void)
{
/* * CONFIGURATION Bits **********************************************/
#ifdef _DEBUG_MODE_
 #pragma config CPUDIV = NOCLKDIV
 #pragma config USBDIV = OFF
 #pragma config FOSC   = HS
 #pragma config PLLEN  = ON
 #pragma config FCMEN  = OFF
 #pragma config IESO   = OFF
 #pragma config PWRTEN = OFF // for debug
 #pragma config BOREN  = OFF
 #pragma config BORV   = 30
 #pragma config WDTEN  = OFF // for debug
 #pragma config WDTPS  = 32768
 #pragma config MCLRE  = ON  // for debug
 #pragma config HFOFST = OFF
 #pragma config STVREN = ON
 #pragma config LVP    = OFF
 #pragma config XINST  = OFF
 #pragma config BBSIZ  = OFF
 #pragma config CP0    = OFF
 #pragma config CP1    = OFF
 #pragma config CPB    = OFF
 #pragma config WRT0   = OFF
 #pragma config WRT1   = OFF
 #pragma config WRTB   = OFF
 #pragma config WRTC   = OFF
 #pragma config EBTR0  = OFF
 #pragma config EBTR1  = OFF
 #pragma config EBTRB  = OFF
#else
 #pragma config CPUDIV = NOCLKDIV
 #pragma config USBDIV = OFF
 #pragma config FOSC   = HS
 #pragma config PLLEN  = ON
 #pragma config FCMEN  = OFF
 #pragma config IESO   = OFF
 #pragma config PWRTEN = OFF
 #pragma config BOREN  = OFF
 #pragma config BORV   = 30
 #pragma config WDTEN  = OFF
 #pragma config WDTPS  = 256
 #pragma config MCLRE  = OFF
 #pragma config HFOFST = OFF
 #pragma config STVREN = ON
 #pragma config LVP    = OFF
 #pragma config XINST  = OFF
 #pragma config BBSIZ  = OFF
 #pragma config CP0    = OFF
 #pragma config CP1    = OFF
 #pragma config CPB    = OFF
 #pragma config WRT0   = OFF
 #pragma config WRT1   = OFF
 #pragma config WRTB   = OFF
 #pragma config WRTC   = OFF
 #pragma config EBTR0  = OFF
 #pragma config EBTR1  = OFF
 #pragma config EBTRB  = OFF
#endif

    pic_init();
    pic_init_enable();
    global_define();

    SYSTEM_Initialize( SYSTEM_STATE_USB_START );

    USBDeviceInit();
    USBDeviceAttach();

    while(1)
    {
        SYSTEM_Tasks();

        #if defined(USB_POLLING)
        /* Check bus status and service USB interrupts.  Interrupt or polling
         * method.  If using polling, must call this function periodically.
         * This function will take care of processing and responding to SETUP
         * transactions (such as during the enumeration process when you first
         * plug in).  USB hosts require that USB devices should accept and
         * process SETUP packets in a timely fashion.  Therefore, when using
         * polling, this function should be called regularly (such as once every
         * 1.8ms or faster** [see inline code comments in usb_device.c for
         * explanation when "or faster" applies])  In most cases, the
         * USBDeviceTasks() function does not take very long to execute
         * (ex: <100 instruction cycles) before it returns. */
        USBDeviceTasks();
        #endif

        /* Run the keyboard demo tasks. */
        APP_KeyboardTasks();
        
        if(timer2_interrupt_glb == INT_ON)
        {
            button_push_detect();
            led_cont(250);
            timer2_interrupt_glb = INT_OFF;
        }
        
        
    }//end while
}//end main

/*******************************************************************************
 End of File
*/
