// ========================== ここから ==============================
//ファイル名    pic_init.c
//作成日     2024.4.6
//更新日     2024.4.6
//作成者     Shimaneko
//バージョン    1.0
//コンパイラ    MPLAB XC8
//ＰＩＣ     PIC18F14K50
//クロック    12MHz EXT PLLx4 48MHz
//
//概要
//     PIC初期化関数
//
// ====================== ここまで ===================================

#include <xc.h>
#include "pic_init.h"
#include "global_define.h"


void pic_init(void) {
/* register setting */

TRISA = 0b00110000;   //RA5-RA4 input for OSC
TRISB = 0b11110000;   //RB7-RB4 input for Push Button
TRISC = 0b00000000;   //RC7-RC5 output for LED Indicator RC2-RC0 Not used

ANSEL = 0b00000000;   //Analog input not used
ANSELH = 0b00000000;   //Analog input not used


//割り込み設定
INTCONbits.GIE_GIEH = 0;  //グローバル割り込みイネーブルビットあとで1にする
INTCONbits.PEIE_GIEL = 1; //周辺割り込みイネーブルビット USART用
INTCONbits.TMR0IE = 0; // TMR0 オーバーフロー割り込みイネーブルビット　TIMER0不使用
INTCONbits.INT0IE = 0; // INT0 外部割り込みイネーブルビット 外部割り込み不使用
INTCONbits.RABIE = 0; // RA およびRB ポート状態変化割り込みイネーブルビット
INTCONbits.TMR0IF = 0; // TMR0 オーバーフロー割り込みフラグビット
INTCONbits.INT0IF = 0; // INT0 外部割り込みフラグビット
INTCONbits.RABIF = 0; // RA およびRB ポート状態変化割り込みフラグビット

INTCON2bits.RABPU = 0; // PORTA およびPORTB プルアップ イネーブルビット プルアップする
INTCON2bits.INTEDG0 = 0; // 外部割り込み0 エッジ選択ビット 不使用
INTCON2bits.INTEDG1 = 0; // 外部割り込み1 エッジ選択ビット 不使用
INTCON2bits.INTEDG2 = 0; // 外部割り込み2 エッジ選択ビット 不使用
INTCON2bits.TMR0IP = 0; // TMR0 オーバーフロー割り込み優先度ビット TIMER0は不使用
INTCON2bits.RABIP = 0; // RA およびRB ポート状態変化割り込み優先度ビット 不使用

INTCON3bits.INT2IP = 0; //INT2 外部割り込み優先度ビット  不使用
INTCON3bits.INT1IP = 0; //INT1 外部割り込み優先度ビット  不使用
INTCON3bits.INT2IE = 0; //INT2 外部割り込みイネーブルビット  不使用
INTCON3bits.INT1IE = 0; //INT1 外部割り込みイネーブルビット 不使用
INTCON3bits.INT2IF = 0; //INT2 外部割り込みフラグビット 不使用
INTCON3bits.INT1IF = 0; //INT1 外部割り込みフラグビット 不使用

PIR1bits.ADIF = 0; // A/D コンバータ割り込みフラグビット 不使用
// PIR1bits.RCIF = 0; // read only EUSART 受信割り込みフラグビット 不使用
// PIR1bits.TXIF = 0; // read only EUSART 送信割り込みフラグビット 不使用
PIR1bits.SSPIF = 0; // マスタ同期シリアルポート割り込みフラグビット 不使用
PIR1bits.CCP1IF = 0; // CCP1 割り込みフラグビット 不使用
PIR1bits.TMR2IF = 0; // TMR2/PR2 一致割り込みフラグビット 使う
PIR1bits.TMR1IF = 0; // TMR1 オーバーフロー割り込みフラグビット  不使用



PIR2bits.OSCFIF = 0; //オシレータ障害割り込みフラグビット   不使用
PIR2bits.C1IF = 0; // コンパレータC1 割り込みフラグビット   不使用
PIR2bits.C2IF = 0; // コンパレータC2 割り込みフラグビット   不使用
PIR2bits.EEIF = 0; // データEEPROM/ フラッシュ書き込み動作割り込みフラグビット   不使用
PIR2bits.BCLIF = 0; // バスコリジョン割り込みフラグビット   不使用
//PIR2bits.USBIF = 0; // USB 割り込みフラグビット usb_hal_pic18.h内で制御しているので触らない
PIR2bits.TMR3IF = 0; //　TMR3 オーバーフロー割り込みフラグビット 不使用

PIE1bits.ADIE = 0; // A/D コンバータ割り込みイネーブルビット 不使用
PIE1bits.RCIE = 0; // EUSART 受信割り込みイネーブルビット あとでON/OFF制御する
PIE1bits.TXIE = 0; // EUSART 送信割り込みイネーブルビット あとでON/OFF制御する
PIE1bits.SSPIE = 0; // マスタ同期シリアルポート割り込みイネーブルビット 不使用
PIE1bits.CCP1IE = 0; // CCP1 割り込みイネーブルビット 不使用
PIE1bits.TMR2IE = 1; // TMR2/PR2 一致割り込みイネーブルビット 使う
PIE1bits.TMR1IE = 0; // TMR1 オーバーフロー割り込みイネーブルビット 不使用


PIE2bits.OSCFIE = 0; // オシレータ障害割り込みイネーブルビット 不使用 
PIE2bits.C1IE = 0; // コンパレータC1 割り込みイネーブルビット 不使用
PIE2bits.C2IE = 0; // コンパレータC2 割り込みイネーブルビット 不使用
PIE2bits.EEIE = 0; // データEEPROM/ フラッシュ書き込み動作割り込みイネーブルビット 不使用
PIE2bits.BCLIE = 0; // バスコリジョン割り込みイネーブルビット 不使用
//PIE2bits.USBIE = 1; // USB 割り込みイネーブルビット 使ってるはず usb_hal_pic18.h内で制御しているので触らない
PIE2bits.TMR3IE = 0; // TMR3 オーバーフロー割り込みイネーブルビット 不使用


 
IPR1bits.ADIP  = 0; // A/D コンバータ割り込み優先度ビット 不使用
IPR1bits.RCIP = 0; // EUSART 受信割り込み優先度ビット 使うけどとりあえず低優先度
IPR1bits.TXIP = 0; // EUSART 送信割り込み優先度ビット 使うけどとりあえず低優先度
IPR1bits.SSPIP = 0; // マスタ同期シリアルポート割り込み優先度ビット 不使用
IPR1bits.CCP1IP = 0; // CCP1 割り込み優先度ビット 不使用
IPR1bits.TMR2IP = 0; // TMR2/PR2 一致割り込み優先度ビット 使うけどとりあえず低優先度
IPR1bits.TMR1IP = 0; // TMR1 オーバーフロー割り込み優先度ビット 不使用

IPR2bits.OSCFIP = 0; // オシレータ障害割り込み優先度ビット 不使用
IPR2bits.C1IP = 0; // コンパレータC1 割り込み優先度ビット 不使用
IPR2bits.C2IP = 0; // コンパレータC2 割り込み優先度ビット 不使用
IPR2bits.EEIP = 0; // データEEPROM/ フラッシュ書き込み動作割り込み優先度ビット 不使用
IPR2bits.BCLIP = 0; // バスコリジョン割り込み優先度ビット 不使用
//IPR2bits.USBIP = 1; // USB 割り込み優先度ビット 使う　とりあえず高優先度  usb_hal_pic18.h内で制御しているので触らない
IPR2bits.TMR3IP = 0; // TMR3 オーバーフロー割り込み優先度ビット 不使用



//RCONbits.IPEN = 1; //割り込み優先度イネーブルビット  usb_hal_pic18.h内で制御しているので触らない
RCONbits.SBOREN = 0; // ソフトウェアBOR イネーブルビット
RCONbits.RI = 1; // RESET 命令フラグビット
// RCONbits.TO //read only ウォッチドッグ タイムアウト フラグビット
// RCONbits.PD //read only パワーダウン検出フラグビット
RCONbits.POR = 1; //パワーオンリセット ステータス ビット
RCONbits.BOR = 1; //ブラウンアウト リセット ステータス ビット

//システムクロック設定
OSCCONbits.IDLEN = 0; // アイドル イネーブル ビット
OSCCONbits.IRCF = 0b011; // 内部オシレータ周波数選択ビット 1MHz
// OSCCONbits.OSTS //read only オシレータ起動タイムアウト ステータス ビット
OSCCONbits.SCS = 0; // システムクロック選択ビット

OSCTUNEbits.INTSRC = 0; //内部オシレータ低周波ソース選択ビット
OSCTUNEbits.SPLLEN = 0; //ソフトウェア制御による周波数マルチプライヤPLL ビット
OSCTUNEbits.TUN = 0; //周波数調整ビット

//Timer0設定
T0CONbits.TMR0ON = 0; //Timer0 ON/OFF 制御ビット 不使用

//Timer1設定
T1CONbits.TMR1ON = 0; //Timer1 ON/OFF 制御ビット 不使用

//Timer2設定
// 48MHz ÷4 ÷ 16 ÷ 200 ÷ 15  = 250Hz 4mS周期
T2CONbits.T2CKPS = 3;        // Timer2 クロック プリスケール値選択ビット 1:16
T2CONbits.T2OUTPS = 0b1110;  // Timer2 出力ポストスケール値選択ビット 1:15
T2CONbits.TMR2ON = 0;        // Timer2 On bit
PR2 = 200;                   // TMR2 overflow setting
PIR1bits.TMR2IF = 0;         // TMR2割り込みフラグをクリア

//Timer3設定
T3CONbits.TMR3ON = 0; //Timer1 ON/OFF 制御ビット 不使用

//入力ピンpull up設定
//RAxはプルアップなし
WPUAbits.WPUA3 = 0;
WPUAbits.WPUA4 = 0;
WPUAbits.WPUA5 = 0;
//RB5-7はプルアップあり
WPUBbits.WPUB4 = 1;
WPUBbits.WPUB5 = 1;
WPUBbits.WPUB6 = 1;
WPUBbits.WPUB7 = 1;

        
// WDT
// WDT のクロック源にはLFINTOSC を使用します。WDT を有効にするとLFINTOSC も有効になります
//周期は4msでWDTPSでプリスケーラ設定する
WDTCONbits.SWDTEN = 0;  //WDT EN


}

void pic_init_enable(void) {
    //いろいろイネーブルにする
    T2CONbits.TMR2ON = 1;        // Timer2 On bit 
    INTCONbits.GIE_GIEH = 1;  //グローバル割り込みイネーブルビットあとで1にする
    
}