/*******************************************************************************
Copyright 2016 Microchip Technology Inc. (www.microchip.com)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

To request to license the code under the MLA license (www.microchip.com/mla_license), 
please contact mla_licensing@microchip.com
*******************************************************************************/

#include "system.h"
#include "usb.h"
#include "global_define.h"


/*********************************************************************
* Function: void SYSTEM_Initialize( SYSTEM_STATE state )
*
* Overview: Initializes the system.
*
* PreCondition: None
*
* Input:  SYSTEM_STATE - the state to initialize the system into
*
* Output: None
*
********************************************************************/
void SYSTEM_Initialize( SYSTEM_STATE state )
{
    switch(state)
    {
        case SYSTEM_STATE_USB_START:
            break;
            
        case SYSTEM_STATE_USB_SUSPEND: 
            break;
            
        case SYSTEM_STATE_USB_RESUME:
            break;
    }
}

#if(__XC8_VERSION < 2000)
    #define INTERRUPT interrupt
#else
    #define INTERRUPT __interrupt()
#endif

void INTERRUPT SYS_InterruptHigh(void)
{
    if(UIRbits.SOFIF == 1 ||
       UIRbits.STALLIF == 1 ||
       UIRbits.IDLEIF == 1 ||
       UIRbits.TRNIF   == 1 ||
       UIRbits.ACTVIF == 1 ||
       UIRbits.UERRIF == 1 ||
       UIRbits.URSTIF ) {
     
        #if defined(USB_INTERRUPT)
            USBDeviceTasks();
        #endif
    }
    #if 1
    else if( (PIR1bits.TMR2IF == 1) && (PIE1bits.TMR2IE == 1) ) {
        // タイマ2割り込みがかかったときの処理
        // 48MHz ÷4 ÷ 64 ÷ 25 ÷ 16  = 468Hz 2.13mS周期
        PIR1bits.TMR2IF = 0; //TMR2割り込みフラグをクリア
        timer2_interrupt_glb = INT_ON; //割り込みがかかったフラグを立てる
           
        //char rtn;
        // rtn = serial_comm_tx(0xAA);
    } 
   
    #endif
}
