/*******************************************************************************
Copyright 2016 Microchip Technology Inc. (www.microchip.com)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

To request to license the code under the MLA license (www.microchip.com/mla_license), 
please contact mla_licensing@microchip.com
*******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************
#include <stdint.h>

#include "usb.h"
#include "usb_device_hid.h"


// *****************************************************************************
// *****************************************************************************
// Section: File Scope or Global Constants
// *****************************************************************************
// *****************************************************************************

//リポートディスクリプタはapp_device_keyboard.cに定義されている

/* Device Descriptor */
// デバイスディスクリプタ
const USB_DEVICE_DESCRIPTOR device_dsc=
{
    0x12,    // Size of this descriptor in bytes ディスクリプタのサイズ　0x12で固定
    USB_DESCRIPTOR_DEVICE,                // DEVICE descriptor type　ディスクリプタのタイプ 1で固定
    0x0200,                 // USB Spec Release Number in BCD format BCD表現でのUSB仕様リリース番号 2.0.0
    0x00,                   // Class Code クラスコード　0:クラスなし 0xFF:ベンダ 1~0xFE:特定
    0x00,                   // Subclass code　サブクラスコード
    0x00,                   // Protocol code　0:固有プロトコル使用せず　0xFF:ベンダ固有
    USB_EP0_BUFF_SIZE,          // Max packet size for EP0, see usb_config.h　　エンドポイント0の最大パケットサイズ
    MY_VID,                 // Vendor ID　ベンダID USB IFが割り当てる　　usb_config.hで宣言されている
    MY_PID,                 // Product ID: Keyboard fw demo　プロダクトID　ベンダが割り当てる　　usb_config.hで宣言されている
    0x0001,                 // Device release number in BCD format　　BCD表現でのデバイスリリース番号
    0x01,                   // Manufacturer string index 製造者を表すストリングディスクリプタへのインデックス
    0x02,                   // Product string index　製品を表すストリングディスクリプタへのインデックス
    0x00,                   // Device serial number string index　　デバイスの製造番号を表すストリングディスクリプタへのインデックス
    0x01                    // Number of possible configurations　構成可能な数
};

/* Configuration 1 Descriptor */
//　コンフィグレーションディスクリプタ
const uint8_t configDescriptor1[]={
    /* Configuration Descriptor */
    0x09,//sizeof(USB_CFG_DSC),    // Size of this descriptor in bytes　　ディスクリプタのサイズ　0x09で固定
    USB_DESCRIPTOR_CONFIGURATION,                // CONFIGURATION descriptor type  ディスクリプタのタイプ　0x02で固定
    DESC_CONFIG_WORD(0x0029),   // Total length of data for this cfg　全体構成(構成、インターフェイス、エンドポイント、その他のディスクリプタ)の長さ
    1,                      // Number of interfaces in this cfg　構成の持つインターフェイスの数
    1,                      // Index value of this configuration　SetConfigurationで、この構成を選択するための引数
    0,                      // Configuration string index　構成を表すストリングディスクリプタへのインデックス
    _DEFAULT | _SELF,               // Attributes, see usb_device.h　構成の特性。ビットで指定。 D7:"1" D6:自己電源 D5:リモートウェークアップ
    50,                     // Max power consumption (2X mA)　　最大バス電流 2mA単位で指定

    /* Interface Descriptor */
	//　インターフェイスディスクリプタ
    0x09,//sizeof(USB_INTF_DSC),   // Size of this descriptor in bytes　　　ディスクリプタのサイズ　0x09で固定
    USB_DESCRIPTOR_INTERFACE,               // INTERFACE descriptor type　　ディスクリプタのタイプ　0x04で固定
    0,                      // Interface Number　　　構成の中で、このインターフェイスを表すインデックス番号(0ベース)
    0,                      // Alternate Setting Number　インターフェイスで代替設定を選択するための引数
    2,                      // Number of endpoints in this intf　　エンドポイント0を除くインターフェイスが持つエンドポイント数
    HID_INTF,               // Class code　　0:クラス無し　0xFF:ベンダ　0x01~0xFE:特定
    BOOT_INTF_SUBCLASS,     // Subclass code
    HID_PROTOCOL_KEYBOARD,     // Protocol code　0:固有プロトコルを使用せず　0xFF:ベンダ固有
    0,                      // Interface string index　このインターフェイスを表すストリングディスクリプタへのインデックス

    /* HID Class-Specific Descriptor */
	// HIDディスクリプタ
    0x09,//sizeof(USB_HID_DSC)+3,    // Size of this descriptor in bytes RRoj hack  ディスクリプタのサイズ　0x09で固定
    DSC_HID,                // HID descriptor type  ディスクリプタのタイプ　0x21で固定
    DESC_CONFIG_WORD(0x0111),                 // HID Spec Release Number in BCD format (1.11)  BCD表現でのHIDバージョン
    0x00,                   // Country Code (0x00 for Not supported)　　地域固有デバイスのための国識別番号(必要がなければ0)
    HID_NUM_OF_DSC,         // Number of class descriptors, see usbcfg.h　　クラスディスクリプターの数
    DSC_RPT,                // Report descriptor type　　クラスディスクリプターの型 (HID Reportの場合0x22)
    DESC_CONFIG_WORD(63),   //sizeof(hid_rpt01),      // Size of the report descriptor　　レポートディスクリプターのサイズ
    
    /* Endpoint Descriptor */
	//エンドポイントディスクリプタ
    0x07,/*sizeof(USB_EP_DSC) ディスクリプタのサイズ 0x07で固定*/
    USB_DESCRIPTOR_ENDPOINT,    //Endpoint Descriptor ディスクリプタのタイプ　0x05で固定
    HID_EP | _EP_IN,            //EndpointAddress　エンドポイントアドレス　ビットで表現 D7:方向 0:OUT 1:IN   D6-D4:予約　　D3-D0エンドポイント番号
    _INTERRUPT,                       //Attributes
    DESC_CONFIG_WORD(8),        //size
    0x20,                        //Interval

    /* Endpoint Descriptor */
    0x07,/*sizeof(USB_EP_DSC)*/
    USB_DESCRIPTOR_ENDPOINT,    //Endpoint Descriptor
    HID_EP | _EP_OUT,            //EndpointAddress
    _INTERRUPT,                       //Attributes
    DESC_CONFIG_WORD(8),        //size
    0x20                        //Interval

};

//Windows上で表示させる文字列の定義
//Language code string descriptor
const struct{uint8_t bLength;uint8_t bDscType;uint16_t string[1];}sd000={
sizeof(sd000),USB_DESCRIPTOR_STRING,{0x0409
}};

//Manufacturer string descriptor
const struct{uint8_t bLength;uint8_t bDscType;uint16_t string[25];}sd001={
sizeof(sd001),USB_DESCRIPTOR_STRING,
{'M','i','c','r','o','c','h','i','p',' ',
'T','e','c','h','n','o','l','o','g','y',' ','I','n','c','.'
}};

//Product string descriptor
const struct{uint8_t bLength;uint8_t bDscType;uint16_t string[13];}sd002={
sizeof(sd002),USB_DESCRIPTOR_STRING,
{'K','e','y','b','o','a','r','d',' ','D','e','m','o'
}};

//Array of configuration descriptors
const uint8_t *const USB_CD_Ptr[]=
{
    (const uint8_t *const)&configDescriptor1
};

//Array of string descriptors
const uint8_t *const USB_SD_Ptr[]=
{
    (const uint8_t *const)&sd000,
    (const uint8_t *const)&sd001,
    (const uint8_t *const)&sd002
};

// *****************************************************************************
// *****************************************************************************
// Section: File Scope Data Types
// *****************************************************************************
// *****************************************************************************


// *****************************************************************************
// *****************************************************************************
// Section: Macros or Functions
// *****************************************************************************
// *****************************************************************************

/*******************************************************************************
 End of File
*/

